---
title: "ABSESpy"
description: "基于智能体的社会生态系统建模框架（Python）"
---
![ABSES_banner](https://songshgeo-picgo-1302043007.cos.ap-beijing.myqcloud.com/uPic/CleanShot%202023-10-19%20at%2019.08.12@2x.png)

**日期**: 2025年2月16日, **版本**: 0.7.x

**有用链接**: [安装](home/Installation.md) | [源代码仓库](https://github.com/SongshGeoLab/ABSESpy) | [问题与建议](https://github.com/SongshGeoLab/ABSESpy/issues) | [问答支持](https://github.com/SongshGeoLab/ABSESpy/discussions)

`ABSESpy` 是一个基于智能体的框架，让社会生态系统建模变得更简单。

<div class="grid cards" markdown>

-   :octicons-question-24:{ .lg .middle } __适合我吗？__

    ---

    还在考虑 `ABSESpy` 是否适合您？
    我们为您准备了一个检查清单。

    [:material-check-all: 指南检查清单](home/guide_checklist.md)

-   :material-clock-fast:{ .lg .middle } __5分钟快速设置__

    ---

    使用 `pip` [安装 `ABSESpy`](home/Installation.md)，然后查看我们的快速开始教程。

    [:material-run-fast: 快速开始](home/get_started.md)

-   :material-scale-balance:{ .lg .middle } __开始建模__

    ---

    我们提供详细的教程帮助用户开始开发自己的ABM模型。

    [:material-book: 教程](tutorial/tutorial.md)

-   :material-api:{ .lg .middle } __API文档__

    ---

    对于高级用户，查看源代码文档。

    [:material-api: API参考](api/api.md)

</div>

## 保持联系

[邮件列表 :fontawesome-solid-paper-plane:](https://groups.google.com/g/absespy){ .md-button }

